excerpts.AllExcerpts (Excerpts) — amici1

# `excerpts.AllExcerpts` (Excerpts)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateTimeField: build_time>`

- `<lino.core.choicelists.ChoiceListField: build_method>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<django.db.models.fields.related.ForeignKey: company>`

- `<django.db.models.fields.related.ForeignKey: contact_person>`

- `<django.db.models.fields.related.ForeignKey: contact_role>`

- `<django.db.models.fields.related.ForeignKey: excerpt_type>`

- `<lino.utils.mldbc.fields.LanguageField: language>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc81d19ed68>`

Detail fields

- `<Panel main_1 in lino_xl.lib.excerpts.models.ExcerptDetail on lino_xl.lib.excerpts.models.Excerpts>`

- `<Panel main_2 in lino_xl.lib.excerpts.models.ExcerptDetail on lino_xl.lib.excerpts.models.Excerpts>`

- `<Panel main_3 in lino_xl.lib.excerpts.models.ExcerptDetail on lino_xl.lib.excerpts.models.Excerpts>`

- `<Panel main_4 in lino_xl.lib.excerpts.models.ExcerptDetail on lino_xl.lib.excerpts.models.Excerpts>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate the selected row.

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Print (do_print) : The action used to print this object. This is an instance of DirectPrintAction or CachedPrintAction by default. And if lino_xl.lib.excerpts is installed, then set_excerpts_actions possibly replaces do_print by a lino_xl.lib.excerpts.CreateExcerpt instance.

- Clear cache (do_clear_cache) : Defines the Clear cache button on a Printable record.

- Check data (check_data) : See `<lino.modlib.checkdata.models.UpdateProblemsByController check_data ('Check data')>`.

- Create email (create_mail) : Creates an outbox mail and displays it.

- Fix data problems (fix_problems) : See `<lino.modlib.checkdata.models.FixProblemsByController fix_problems ('Fix data problems')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<django.db.models.fields.related.ForeignKey: excerpt_type>`

- `<lino.core.choicelists.ChoiceListField: pcertifying>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<lino.core.fields.DummyField object at 0x7fc81ce6b710>`

- `<django.db.models.fields.related.ForeignKey: user>`

## Filter parameters